@@ -1,8 +1,6 @@
 /*
  * pommed - Apple laptops hotkeys handler daemon
  *
- * $Id: evdev.c 541 2009-01-03 18:07:38Z jblache $
- *
  * Copyright (C) 2006-2009 Julien BLACHE <jb@jblache.org>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -71,6 +69,8 @@ static int
 evdev_try_add(int fd);
 
 
+static int internal_kbd_fd;
+
 void
 evdev_process_events(int fd, uint32_t events)
 {
@@ -87,6 +87,9 @@ evdev_process_events(int fd, uint32_t events)
       if (ret < 0)
 	logmsg(LOG_ERR, "Could not remove device from event loop");
 
+      if (fd == internal_kbd_fd)
+	internal_kbd_fd = -1;
+
       close(fd);
 
       return;
@@ -104,8 +107,11 @@ evdev_process_events(int fd, uint32_t events)
 	return;
 
       /* Reset keyboard backlight idle timer */
-      kbd_bck_info.idle = 0;
-      kbd_backlight_inhibit_clear(KBD_INHIBIT_IDLE);
+      if (fd == internal_kbd_fd)
+	{
+	  kbd_bck_info.idle = 0;
+	  kbd_backlight_inhibit_clear(KBD_INHIBIT_IDLE);
+	}
 
       switch (ev.code)
 	{
@@ -682,6 +688,32 @@ evdev_is_extkbd_white(unsigned short *id)
   return 0;
 }
 
+/* Apple external USB mini keyboard, aluminium */
+static int
+evdev_is_extkbd_mini_alu(unsigned short *id)
+{
+  unsigned short product = id[ID_PRODUCT];
+
+  if (id[ID_BUS] != BUS_USB)
+    return 0;
+
+  if (id[ID_VENDOR] != USB_VENDOR_ID_APPLE)
+    return 0;
+
+  if ((product == USB_PRODUCT_ID_APPLE_EXTKBD_MINI_ALU_ANSI)
+      || (product == USB_PRODUCT_ID_APPLE_EXTKBD_MINI_ALU_ISO)
+      || (product == USB_PRODUCT_ID_APPLE_EXTKBD_MINI_ALU_JIS))
+    {
+      logdebug(" -> External Apple USB mini keyboard (aluminium)\n");
+
+      kbd_set_fnmode();
+
+      return 1;
+    }
+
+  return 0;
+}
+
 /* Apple external USB keyboard, aluminium */
 static int
 evdev_is_extkbd_alu(unsigned short *id)
@@ -739,6 +771,7 @@ static int
 evdev_is_extkbd(unsigned short *id)
 {
   return (evdev_is_extkbd_white(id)
+	  || evdev_is_extkbd_mini_alu(id)
 	  || evdev_is_extkbd_alu(id)
 	  || evdev_is_extkbd_alu_wl(id));
 }
@@ -824,11 +857,27 @@ evdev_try_add(int fd)
       return -1;
     }
 
+  /* There are 2 keyboards, but one of them only has the eject key;
+     the real keyboard has all the keys and the LEDs. Checking for
+     the LEDs is a quick way of identifying the keyboard we want.
+  */
+  if (test_bit(EV_LED, bit[0]) && evdev_is_internal(id))
+    {
+      logdebug(" -> Internal keyboard\n");
+
+      internal_kbd_fd = fd;
+    }
+
   ret = evloop_add(fd, EPOLLIN, evdev_process_events);
   if (ret < 0)
     {
       logmsg(LOG_ERR, "Could not add device to event loop");
 
+      if (fd == internal_kbd_fd)
+	internal_kbd_fd = -1;
+
+      close(fd);
+
       return -1;
     }
 
@@ -886,6 +935,8 @@ evdev_init(void)
   int ndevs;
   int fd;
 
+  internal_kbd_fd = -1;
+
   ndevs = 0;
   for (i = 0; i < EVDEV_MAX; i++)
     {
