@@ -1,8 +1,6 @@
 /*
  * wmpomme -- WindowMaker dockapp for use with pommed
  *
- * $Id: wmpomme.c 515 2008-11-09 15:56:32Z jblache $
- *
  * Copyright (C) 2006-2008 Julien BLACHE <jb@jblache.org>
  *
  * Based on wmwave by Carsten Schuermann <carsten@schuermann.org>
@@ -49,7 +47,11 @@
 
 #include <dbus/dbus.h>
 
-#include "timerfd-syscalls.h"
+#ifndef NO_SYS_TIMERFD_H
+# include <sys/timerfd.h>
+#else
+# include "timerfd-syscalls.h"
+#endif
 
 #include "wmgeneral.h"
 #include "wmpomme-master.xpm"
